Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2)

Unified Diff: tests/dartino_tests/verb_tests.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/dartino_tests/utils.dart ('k') | tests/dartino_tests/zone_helper_tests.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/dartino_tests/verb_tests.dart
diff --git a/tests/fletch_tests/verb_tests.dart b/tests/dartino_tests/verb_tests.dart
similarity index 75%
rename from tests/fletch_tests/verb_tests.dart
rename to tests/dartino_tests/verb_tests.dart
index a8d16f518345e0cf45fe75b9e6cabe5e0f6bfa09..7313d14a5e178a94474e1d2cf18a20486058782e 100644
--- a/tests/fletch_tests/verb_tests.dart
+++ b/tests/dartino_tests/verb_tests.dart
@@ -3,7 +3,7 @@
// BSD-style license that can be found in the LICENSE.md file.
/// Tests for verbs.
-library fletch_tests.verb_tests;
+library dartino_tests.verb_tests;
import 'dart:async' show
Future;
@@ -11,16 +11,16 @@ import 'dart:async' show
import 'package:expect/expect.dart' show
Expect;
-import 'package:fletchc/src/verbs/help_verb.dart' as help_verb;
+import 'package:dartino_compiler/src/verbs/help_verb.dart' as help_verb;
/// Test verifies that the help text is the right shape.
///
/// The documentation should fit into 80 columns by 20 lines.
/// The default terminal size is normally 80x24. Two lines are used for the
/// prompts before and after running fletch. Another two lines may be
/// used to print an error message.
///
/// See commonActions in package:fletchc/src/verbs/actions.dart.
Future testHelpTextFormatCompliance() async {
// The generation of the help text will self check format compliance.
« no previous file with comments | « tests/dartino_tests/utils.dart ('k') | tests/dartino_tests/zone_helper_tests.dart » ('j') | no next file with comments »
@@ -11,16 +11,16 @@ import 'dart:async' show
/// The documentation should fit into 80 columns by 20 lines.
/// The default terminal size is normally 80x24. Two lines are used for the
-/// prompts before and after running fletch. Another two lines may be
+/// prompts before and after running dartino. Another two lines may be
/// used to print an error message.
///
@@ -11,16 +11,16 @@ import 'dart:async' show
/// used to print an error message.
///
-/// See commonActions in package:fletchc/src/verbs/actions.dart.
+/// See commonActions in package:dartino_compiler/src/verbs/actions.dart.
Future testHelpTextFormatCompliance() async {
// The generation of the help text will self check format compliance.

Powered by Google App Engine
This is Rietveld 408576698